@@ -10,9 +10,20 @@ class _MenuItem(BaseModel):
     """Generic menu item contribution."""
 
     when: Optional[str] = Field(
-        description="Condition which must be true to show this item"
+        description="Condition which must be true to *show* this item in the menu. "
+        "Note that ``when`` clauses apply to menus and ``enablement`` clauses to "
+        "commands. The ``enablement`` applies to all menus and even keybindings while "
+        "the ``when`` only applies to a single menu."
+    )
+    # TODO: declare groups for every menu exposed by napari:
+    # e.g. `2_compare`, `4_search`, `6_cutcopypaste`
+    group: Optional[str] = Field(
+        description="The `group` property defines sorting and grouping of menu items. "
+        "The `'navigation'` group is special: it will always be sorted to the "
+        "top/beginning of a menu. By default, the order *inside* a group depends on "
+        "the `title`. The group-local order of a menu item can be specified by "
+        "appending @<int> to the group identifier: e.g. `group: 'myGroup@2'`."
     )
-    group: Optional[str] = Field(description="Group into which this item belongs")
 
 
 class Submenu(_MenuItem):
