@@ -18,22 +18,17 @@ from typing import (
     Union,
 )
 
+from pydantic import PrivateAttr
+from pydantic.generics import GenericModel
+
 from ..types import PythonName
 
 if TYPE_CHECKING:
-    from typing import Protocol
-
     from npe2.manifest.schema import PluginManifest
 
     from .._command_registry import CommandRegistry
     from .contributions import ContributionPoints
 
-    class ProvidesCommand(Protocol):
-        command: str
-
-        def get_callable(self, _registry: Optional[CommandRegistry] = None):
-            ...
-
 
 def v1_to_v2(path):
     return (path, True) if isinstance(path, list) else ([path], False)
@@ -51,11 +46,13 @@ SHIM_NAME_PREFIX = "__npe1shim__."
 
 
 # TODO: add ParamSpec when it's supported better by mypy
-class Executable(Generic[R]):
+class Executable(GenericModel, Generic[R]):
     command: str
+    # plugin_name gets populated in `PluginManifest.__init__`
+    _plugin_name: str = PrivateAttr("")
 
     def exec(
-        self: ProvidesCommand,
+        self,
         args: tuple = (),
         kwargs: dict = None,
         _registry: Optional[CommandRegistry] = None,
@@ -65,7 +62,7 @@ class Executable(Generic[R]):
         return self.get_callable(_registry)(*args, **kwargs)
 
     def get_callable(
-        self: ProvidesCommand,
+        self,
         _registry: Optional[CommandRegistry] = None,
     ) -> Callable[..., R]:
         if _registry is None:
@@ -75,9 +72,27 @@ class Executable(Generic[R]):
         return _registry.get(self.command)
 
     @property
-    def plugin_name(self: ProvidesCommand):
-        # takes advantage of the fact that command always starts with manifest.name
-        return self.command.split(".")[0]
+    def plugin_name(self) -> str:
+        """Return the manifest/plugin name for this contribution."""
+        if not self._plugin_name:
+            # we will likely never get here if the contribution was created
+            # as a member of a PluginManifest.
+            # But if not, we can use a couple heuristics...
+            from importlib.metadata import distributions
+
+            # look for a package name in the command id
+            dists = sorted(
+                (d.metadata["Name"] for d in distributions()), key=len, reverse=True
+            )
+            for name in dists:
+                if self.command.startswith(name):  # pragma: no cover
+                    self._plugin_name = name
+                    break
+            else:
+                # just split on the first period.
+                # Will break for package names with periods
+                self._plugin_name = self.command.split(".")[0]
+        return self._plugin_name
 
 
 @total_ordering
@@ -273,9 +288,10 @@ def merge_manifests(
     assert (
         len({mf.package_version for mf in manifests}) == 1
     ), "All manifests must have same version"
-    assert (
-        len({mf.display_name for mf in manifests}) == 1
-    ), "All manifests must have same display_name"
+    if not overwrite:
+        assert (
+            len({mf.display_name for mf in manifests}) == 1
+        ), "All manifests must have same display_name"
 
     mf0 = manifests[0]
     info = mf0.dict(exclude={"contributions"}, exclude_unset=True)
